# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class FormProperty(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'type': 'str',
        'value': 'str',
        'writable': 'bool',
        'required': 'bool',
        'enum_values': 'list[DropdownValue]',
        'check_buttons': 'list[OptionValue]',
        'radio_buttons': 'list[OptionValue]',
        'default_dropdown_values': 'list[DropdownValue]',
        'proposed_dropdown_values': 'list[DropdownValue]',
        'date_time_type': 'str',
        'multi_value': 'bool',
        'proposed_fixed': 'bool',
        'default_from_resource': 'bool',
        'multi_default_dropdown_values': 'dict(str, list[DropdownValue])',
        'multi_proposed_dropdown_values': 'dict(str, list[DropdownValue])',
        'asset_type': 'ResourceReference',
        'community_ids': 'list[str]',
        'domain_ids': 'list[str]',
        'status_ids': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'type': 'type',
        'value': 'value',
        'writable': 'writable',
        'required': 'required',
        'enum_values': 'enumValues',
        'check_buttons': 'checkButtons',
        'radio_buttons': 'radioButtons',
        'default_dropdown_values': 'defaultDropdownValues',
        'proposed_dropdown_values': 'proposedDropdownValues',
        'date_time_type': 'dateTimeType',
        'multi_value': 'multiValue',
        'proposed_fixed': 'proposedFixed',
        'default_from_resource': 'defaultFromResource',
        'multi_default_dropdown_values': 'multiDefaultDropdownValues',
        'multi_proposed_dropdown_values': 'multiProposedDropdownValues',
        'asset_type': 'assetType',
        'community_ids': 'communityIds',
        'domain_ids': 'domainIds',
        'status_ids': 'statusIds'
    }

    def __init__(self, id=None, name=None, type=None, value=None, writable=None, required=None, enum_values=None, check_buttons=None, radio_buttons=None, default_dropdown_values=None, proposed_dropdown_values=None, date_time_type=None, multi_value=None, proposed_fixed=None, default_from_resource=None, multi_default_dropdown_values=None, multi_proposed_dropdown_values=None, asset_type=None, community_ids=None, domain_ids=None, status_ids=None, local_vars_configuration=None):  # noqa: E501
        """FormProperty - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._type = None
        self._value = None
        self._writable = None
        self._required = None
        self._enum_values = None
        self._check_buttons = None
        self._radio_buttons = None
        self._default_dropdown_values = None
        self._proposed_dropdown_values = None
        self._date_time_type = None
        self._multi_value = None
        self._proposed_fixed = None
        self._default_from_resource = None
        self._multi_default_dropdown_values = None
        self._multi_proposed_dropdown_values = None
        self._asset_type = None
        self._community_ids = None
        self._domain_ids = None
        self._status_ids = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if value is not None:
            self.value = value
        if writable is not None:
            self.writable = writable
        if required is not None:
            self.required = required
        if enum_values is not None:
            self.enum_values = enum_values
        if check_buttons is not None:
            self.check_buttons = check_buttons
        if radio_buttons is not None:
            self.radio_buttons = radio_buttons
        if default_dropdown_values is not None:
            self.default_dropdown_values = default_dropdown_values
        if proposed_dropdown_values is not None:
            self.proposed_dropdown_values = proposed_dropdown_values
        if date_time_type is not None:
            self.date_time_type = date_time_type
        if multi_value is not None:
            self.multi_value = multi_value
        if proposed_fixed is not None:
            self.proposed_fixed = proposed_fixed
        if default_from_resource is not None:
            self.default_from_resource = default_from_resource
        if multi_default_dropdown_values is not None:
            self.multi_default_dropdown_values = multi_default_dropdown_values
        if multi_proposed_dropdown_values is not None:
            self.multi_proposed_dropdown_values = multi_proposed_dropdown_values
        if asset_type is not None:
            self.asset_type = asset_type
        if community_ids is not None:
            self.community_ids = community_ids
        if domain_ids is not None:
            self.domain_ids = domain_ids
        if status_ids is not None:
            self.status_ids = status_ids

    @property
    def id(self):
        """Gets the id of this FormProperty.  # noqa: E501

        The id of the property.  # noqa: E501

        :return: The id of this FormProperty.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FormProperty.

        The id of the property.  # noqa: E501

        :param id: The id of this FormProperty.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FormProperty.  # noqa: E501

        The name of the property.  # noqa: E501

        :return: The name of this FormProperty.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FormProperty.

        The name of the property.  # noqa: E501

        :param name: The name of this FormProperty.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this FormProperty.  # noqa: E501

        The property type.  # noqa: E501

        :return: The type of this FormProperty.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this FormProperty.

        The property type.  # noqa: E501

        :param type: The type of this FormProperty.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def value(self):
        """Gets the value of this FormProperty.  # noqa: E501

        The property (default) value.  # noqa: E501

        :return: The value of this FormProperty.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this FormProperty.

        The property (default) value.  # noqa: E501

        :param value: The value of this FormProperty.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def writable(self):
        """Gets the writable of this FormProperty.  # noqa: E501

        Whether the property is writable.  # noqa: E501

        :return: The writable of this FormProperty.  # noqa: E501
        :rtype: bool
        """
        return self._writable

    @writable.setter
    def writable(self, writable):
        """Sets the writable of this FormProperty.

        Whether the property is writable.  # noqa: E501

        :param writable: The writable of this FormProperty.  # noqa: E501
        :type: bool
        """

        self._writable = writable

    @property
    def required(self):
        """Gets the required of this FormProperty.  # noqa: E501

        Whether the property is required.  # noqa: E501

        :return: The required of this FormProperty.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this FormProperty.

        Whether the property is required.  # noqa: E501

        :param required: The required of this FormProperty.  # noqa: E501
        :type: bool
        """

        self._required = required

    @property
    def enum_values(self):
        """Gets the enum_values of this FormProperty.  # noqa: E501

        The property's enum values.  # noqa: E501

        :return: The enum_values of this FormProperty.  # noqa: E501
        :rtype: list[DropdownValue]
        """
        return self._enum_values

    @enum_values.setter
    def enum_values(self, enum_values):
        """Sets the enum_values of this FormProperty.

        The property's enum values.  # noqa: E501

        :param enum_values: The enum_values of this FormProperty.  # noqa: E501
        :type: list[DropdownValue]
        """

        self._enum_values = enum_values

    @property
    def check_buttons(self):
        """Gets the check_buttons of this FormProperty.  # noqa: E501

        The property's checkbox buttons.  # noqa: E501

        :return: The check_buttons of this FormProperty.  # noqa: E501
        :rtype: list[OptionValue]
        """
        return self._check_buttons

    @check_buttons.setter
    def check_buttons(self, check_buttons):
        """Sets the check_buttons of this FormProperty.

        The property's checkbox buttons.  # noqa: E501

        :param check_buttons: The check_buttons of this FormProperty.  # noqa: E501
        :type: list[OptionValue]
        """

        self._check_buttons = check_buttons

    @property
    def radio_buttons(self):
        """Gets the radio_buttons of this FormProperty.  # noqa: E501

        The property's radio buttons.  # noqa: E501

        :return: The radio_buttons of this FormProperty.  # noqa: E501
        :rtype: list[OptionValue]
        """
        return self._radio_buttons

    @radio_buttons.setter
    def radio_buttons(self, radio_buttons):
        """Sets the radio_buttons of this FormProperty.

        The property's radio buttons.  # noqa: E501

        :param radio_buttons: The radio_buttons of this FormProperty.  # noqa: E501
        :type: list[OptionValue]
        """

        self._radio_buttons = radio_buttons

    @property
    def default_dropdown_values(self):
        """Gets the default_dropdown_values of this FormProperty.  # noqa: E501

        The property's default dropdown values.  # noqa: E501

        :return: The default_dropdown_values of this FormProperty.  # noqa: E501
        :rtype: list[DropdownValue]
        """
        return self._default_dropdown_values

    @default_dropdown_values.setter
    def default_dropdown_values(self, default_dropdown_values):
        """Sets the default_dropdown_values of this FormProperty.

        The property's default dropdown values.  # noqa: E501

        :param default_dropdown_values: The default_dropdown_values of this FormProperty.  # noqa: E501
        :type: list[DropdownValue]
        """

        self._default_dropdown_values = default_dropdown_values

    @property
    def proposed_dropdown_values(self):
        """Gets the proposed_dropdown_values of this FormProperty.  # noqa: E501

        The property's proposed dropdown values.  # noqa: E501

        :return: The proposed_dropdown_values of this FormProperty.  # noqa: E501
        :rtype: list[DropdownValue]
        """
        return self._proposed_dropdown_values

    @proposed_dropdown_values.setter
    def proposed_dropdown_values(self, proposed_dropdown_values):
        """Sets the proposed_dropdown_values of this FormProperty.

        The property's proposed dropdown values.  # noqa: E501

        :param proposed_dropdown_values: The proposed_dropdown_values of this FormProperty.  # noqa: E501
        :type: list[DropdownValue]
        """

        self._proposed_dropdown_values = proposed_dropdown_values

    @property
    def date_time_type(self):
        """Gets the date_time_type of this FormProperty.  # noqa: E501

        The datetime type in case the property is of type datetime.  # noqa: E501

        :return: The date_time_type of this FormProperty.  # noqa: E501
        :rtype: str
        """
        return self._date_time_type

    @date_time_type.setter
    def date_time_type(self, date_time_type):
        """Sets the date_time_type of this FormProperty.

        The datetime type in case the property is of type datetime.  # noqa: E501

        :param date_time_type: The date_time_type of this FormProperty.  # noqa: E501
        :type: str
        """

        self._date_time_type = date_time_type

    @property
    def multi_value(self):
        """Gets the multi_value of this FormProperty.  # noqa: E501

        Whether the property allows multiple values.  # noqa: E501

        :return: The multi_value of this FormProperty.  # noqa: E501
        :rtype: bool
        """
        return self._multi_value

    @multi_value.setter
    def multi_value(self, multi_value):
        """Sets the multi_value of this FormProperty.

        Whether the property allows multiple values.  # noqa: E501

        :param multi_value: The multi_value of this FormProperty.  # noqa: E501
        :type: bool
        """

        self._multi_value = multi_value

    @property
    def proposed_fixed(self):
        """Gets the proposed_fixed of this FormProperty.  # noqa: E501

        Whether the property's proposed values are the only set of allowed values to select.  # noqa: E501

        :return: The proposed_fixed of this FormProperty.  # noqa: E501
        :rtype: bool
        """
        return self._proposed_fixed

    @proposed_fixed.setter
    def proposed_fixed(self, proposed_fixed):
        """Sets the proposed_fixed of this FormProperty.

        Whether the property's proposed values are the only set of allowed values to select.  # noqa: E501

        :param proposed_fixed: The proposed_fixed of this FormProperty.  # noqa: E501
        :type: bool
        """

        self._proposed_fixed = proposed_fixed

    @property
    def default_from_resource(self):
        """Gets the default_from_resource of this FormProperty.  # noqa: E501

        Whether the property's default value is the current resource.  # noqa: E501

        :return: The default_from_resource of this FormProperty.  # noqa: E501
        :rtype: bool
        """
        return self._default_from_resource

    @default_from_resource.setter
    def default_from_resource(self, default_from_resource):
        """Sets the default_from_resource of this FormProperty.

        Whether the property's default value is the current resource.  # noqa: E501

        :param default_from_resource: The default_from_resource of this FormProperty.  # noqa: E501
        :type: bool
        """

        self._default_from_resource = default_from_resource

    @property
    def multi_default_dropdown_values(self):
        """Gets the multi_default_dropdown_values of this FormProperty.  # noqa: E501

        The multi default dropdown values.  # noqa: E501

        :return: The multi_default_dropdown_values of this FormProperty.  # noqa: E501
        :rtype: dict(str, list[DropdownValue])
        """
        return self._multi_default_dropdown_values

    @multi_default_dropdown_values.setter
    def multi_default_dropdown_values(self, multi_default_dropdown_values):
        """Sets the multi_default_dropdown_values of this FormProperty.

        The multi default dropdown values.  # noqa: E501

        :param multi_default_dropdown_values: The multi_default_dropdown_values of this FormProperty.  # noqa: E501
        :type: dict(str, list[DropdownValue])
        """

        self._multi_default_dropdown_values = multi_default_dropdown_values

    @property
    def multi_proposed_dropdown_values(self):
        """Gets the multi_proposed_dropdown_values of this FormProperty.  # noqa: E501

        The multi proposed dropdown values.  # noqa: E501

        :return: The multi_proposed_dropdown_values of this FormProperty.  # noqa: E501
        :rtype: dict(str, list[DropdownValue])
        """
        return self._multi_proposed_dropdown_values

    @multi_proposed_dropdown_values.setter
    def multi_proposed_dropdown_values(self, multi_proposed_dropdown_values):
        """Sets the multi_proposed_dropdown_values of this FormProperty.

        The multi proposed dropdown values.  # noqa: E501

        :param multi_proposed_dropdown_values: The multi_proposed_dropdown_values of this FormProperty.  # noqa: E501
        :type: dict(str, list[DropdownValue])
        """

        self._multi_proposed_dropdown_values = multi_proposed_dropdown_values

    @property
    def asset_type(self):
        """Gets the asset_type of this FormProperty.  # noqa: E501


        :return: The asset_type of this FormProperty.  # noqa: E501
        :rtype: ResourceReference
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this FormProperty.


        :param asset_type: The asset_type of this FormProperty.  # noqa: E501
        :type: ResourceReference
        """

        self._asset_type = asset_type

    @property
    def community_ids(self):
        """Gets the community_ids of this FormProperty.  # noqa: E501

        Community ids.  # noqa: E501

        :return: The community_ids of this FormProperty.  # noqa: E501
        :rtype: list[str]
        """
        return self._community_ids

    @community_ids.setter
    def community_ids(self, community_ids):
        """Sets the community_ids of this FormProperty.

        Community ids.  # noqa: E501

        :param community_ids: The community_ids of this FormProperty.  # noqa: E501
        :type: list[str]
        """

        self._community_ids = community_ids

    @property
    def domain_ids(self):
        """Gets the domain_ids of this FormProperty.  # noqa: E501

        Domain ids.  # noqa: E501

        :return: The domain_ids of this FormProperty.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_ids

    @domain_ids.setter
    def domain_ids(self, domain_ids):
        """Sets the domain_ids of this FormProperty.

        Domain ids.  # noqa: E501

        :param domain_ids: The domain_ids of this FormProperty.  # noqa: E501
        :type: list[str]
        """

        self._domain_ids = domain_ids

    @property
    def status_ids(self):
        """Gets the status_ids of this FormProperty.  # noqa: E501

        Status ids.  # noqa: E501

        :return: The status_ids of this FormProperty.  # noqa: E501
        :rtype: list[str]
        """
        return self._status_ids

    @status_ids.setter
    def status_ids(self, status_ids):
        """Sets the status_ids of this FormProperty.

        Status ids.  # noqa: E501

        :param status_ids: The status_ids of this FormProperty.  # noqa: E501
        :type: list[str]
        """

        self._status_ids = status_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormProperty):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FormProperty):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ComplexRelationLegTypeRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'min': 'int',
        'max': 'int',
        'role': 'str',
        'co_role': 'str',
        'asset_type_id': 'str',
        'id': 'str',
        'relation_type_id': 'str'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'role': 'role',
        'co_role': 'coRole',
        'asset_type_id': 'assetTypeId',
        'id': 'id',
        'relation_type_id': 'relationTypeId'
    }

    def __init__(self, min=None, max=None, role=None, co_role=None, asset_type_id=None, id=None, relation_type_id=None, local_vars_configuration=None):  # noqa: E501
        """ComplexRelationLegTypeRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._min = None
        self._max = None
        self._role = None
        self._co_role = None
        self._asset_type_id = None
        self._id = None
        self._relation_type_id = None
        self.discriminator = None

        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        self.role = role
        if co_role is not None:
            self.co_role = co_role
        self.asset_type_id = asset_type_id
        if id is not None:
            self.id = id
        if relation_type_id is not None:
            self.relation_type_id = relation_type_id

    @property
    def min(self):
        """Gets the min of this ComplexRelationLegTypeRequest.  # noqa: E501

        The minimum number of Leg Type occurrences.  # noqa: E501

        :return: The min of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: int
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this ComplexRelationLegTypeRequest.

        The minimum number of Leg Type occurrences.  # noqa: E501

        :param min: The min of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: int
        """

        self._min = min

    @property
    def max(self):
        """Gets the max of this ComplexRelationLegTypeRequest.  # noqa: E501

        The maximum number of Leg Type occurrences.  # noqa: E501

        :return: The max of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this ComplexRelationLegTypeRequest.

        The maximum number of Leg Type occurrences.  # noqa: E501

        :param max: The max of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: int
        """

        self._max = max

    @property
    def role(self):
        """Gets the role of this ComplexRelationLegTypeRequest.  # noqa: E501

        The name of the role that the source plays.  # noqa: E501

        :return: The role of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ComplexRelationLegTypeRequest.

        The name of the role that the source plays.  # noqa: E501

        :param role: The role of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and role is None:  # noqa: E501
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501

        self._role = role

    @property
    def co_role(self):
        """Gets the co_role of this ComplexRelationLegTypeRequest.  # noqa: E501

        The name of the role that the target plays.  # noqa: E501

        :return: The co_role of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._co_role

    @co_role.setter
    def co_role(self, co_role):
        """Sets the co_role of this ComplexRelationLegTypeRequest.

        The name of the role that the target plays.  # noqa: E501

        :param co_role: The co_role of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: str
        """

        self._co_role = co_role

    @property
    def asset_type_id(self):
        """Gets the asset_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501

        The ID of the Asset Type of the Relation.<br/>In the next major release, this parameter will only be valid when adding a new leg to the ComplexRelationType. Changing the Asset Type of an existing leg won't be allowed and will result in an error.  # noqa: E501

        :return: The asset_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._asset_type_id

    @asset_type_id.setter
    def asset_type_id(self, asset_type_id):
        """Sets the asset_type_id of this ComplexRelationLegTypeRequest.

        The ID of the Asset Type of the Relation.<br/>In the next major release, this parameter will only be valid when adding a new leg to the ComplexRelationType. Changing the Asset Type of an existing leg won't be allowed and will result in an error.  # noqa: E501

        :param asset_type_id: The asset_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and asset_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `asset_type_id`, must not be `None`")  # noqa: E501

        self._asset_type_id = asset_type_id

    @property
    def id(self):
        """Gets the id of this ComplexRelationLegTypeRequest.  # noqa: E501

        The id of the Complex Relation Leg Type. The Leg Type will be created with this id or updated.<br/>If left empty on update the Leg Type will be recreated.  # noqa: E501

        :return: The id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ComplexRelationLegTypeRequest.

        The id of the Complex Relation Leg Type. The Leg Type will be created with this id or updated.<br/>If left empty on update the Leg Type will be recreated.  # noqa: E501

        :param id: The id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def relation_type_id(self):
        """Gets the relation_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501

        The id of Relation Type of the Leg Type.  # noqa: E501

        :return: The relation_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :rtype: str
        """
        return self._relation_type_id

    @relation_type_id.setter
    def relation_type_id(self, relation_type_id):
        """Sets the relation_type_id of this ComplexRelationLegTypeRequest.

        The id of Relation Type of the Leg Type.  # noqa: E501

        :param relation_type_id: The relation_type_id of this ComplexRelationLegTypeRequest.  # noqa: E501
        :type: str
        """

        self._relation_type_id = relation_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComplexRelationLegTypeRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ComplexRelationLegTypeRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.comment import Comment  # noqa: E501
from collibra_core.rest import ApiException

class TestComment(unittest.TestCase):
    """Comment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Comment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.comment.Comment()  # noqa: E501
        if include_optional :
            return Comment(
                id = '0', 
                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                created_on = 1475503010320, 
                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                last_modified_on = 1476703764163, 
                system = True, 
                resource_type = 'View', 
                content = '0', 
                mentioned_users = [
                    collibra_core.models.user.User(
                        id = '0', 
                        created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                        created_on = 1475503010320, 
                        last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                        last_modified_on = 1476703764163, 
                        system = True, 
                        resource_type = 'View', 
                        user_name = '0', 
                        first_name = '0', 
                        last_name = '0', 
                        email_address = '0', 
                        gender = 'MALE', 
                        language = '0', 
                        additional_email_addresses = [
                            collibra_core.models.email.Email(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                email_address = '0', )
                            ], 
                        phone_numbers = [
                            collibra_core.models.phone_number.PhoneNumber(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                type = 'FAX', 
                                phone_number = '0', )
                            ], 
                        instant_messaging_accounts = [
                            collibra_core.models.instant_messaging_account.InstantMessagingAccount(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                account = '0', 
                                type = 'AOL', )
                            ], 
                        websites = [
                            collibra_core.models.website.Website(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                url = '0', 
                                type = 'FACEBOOK', )
                            ], 
                        addresses = [
                            collibra_core.models.address.Address(
                                id = '0', 
                                created_by = '4d250cc5-e583-4640-9874-b93d82c7a6cb', 
                                created_on = 1475503010320, 
                                last_modified_by = 'a073ff90-e7bc-4b35-ba90-c4d475f642fe', 
                                last_modified_on = 1476703764163, 
                                system = True, 
                                resource_type = 'View', 
                                city = '0', 
                                street = '0', 
                                number = '0', 
                                state = '0', 
                                country = '0', 
                                postal_code = '0', 
                                type = 'HOME', )
                            ], 
                        activated = True, 
                        enabled = True, 
                        ldap_user = True, 
                        user_source = 'INTERNAL', 
                        guest_user = True, 
                        api_user = True, 
                        license_type = 'CONSUMER', )
                    ], 
                base_resource = collibra_core.models.resource_reference.ResourceReference(
                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                    resource_type = 'Community', ), 
                parent = collibra_core.models.resource_reference.ResourceReference(
                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                    resource_type = 'Community', )
            )
        else :
            return Comment(
                id = '0',
                resource_type = 'View',
                base_resource = collibra_core.models.resource_reference.ResourceReference(
                    id = '2b7f3a1a-4e50-4077-96f0-a58a395c860d', 
                    resource_type = 'Community', ),
        )

    def testComment(self):
        """Test Comment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class OutputModuleApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def export_csv(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the results immediately in CSV format.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is <code>false</code> for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>.
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>.
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_csv_with_http_info(**kwargs)  # noqa: E501

    def export_csv_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the results immediately in CSV format.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is <code>false</code> for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>.
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>.
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'separator',
            'quote',
            'escape',
            'header_row',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_csv" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'separator' in local_var_params and local_var_params['separator'] is not None:  # noqa: E501
            query_params.append(('separator', local_var_params['separator']))  # noqa: E501
        if 'quote' in local_var_params and local_var_params['quote'] is not None:  # noqa: E501
            query_params.append(('quote', local_var_params['quote']))  # noqa: E501
        if 'escape' in local_var_params and local_var_params['escape'] is not None:  # noqa: E501
            query_params.append(('escape', local_var_params['escape']))  # noqa: E501
        if 'header_row' in local_var_params and local_var_params['header_row'] is not None:  # noqa: E501
            query_params.append(('headerRow', local_var_params['header_row']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/csv', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_csv_in_job(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in CSV format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>.
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>.
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_csv_in_job_with_http_info(**kwargs)  # noqa: E501

    def export_csv_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in CSV format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>.
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>.
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'separator',
            'quote',
            'escape',
            'header_row',
            'send_notification',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_csv_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'separator' in local_var_params and local_var_params['separator'] is not None:  # noqa: E501
            query_params.append(('separator', local_var_params['separator']))  # noqa: E501
        if 'quote' in local_var_params and local_var_params['quote'] is not None:  # noqa: E501
            query_params.append(('quote', local_var_params['quote']))  # noqa: E501
        if 'escape' in local_var_params and local_var_params['escape'] is not None:  # noqa: E501
            query_params.append(('escape', local_var_params['escape']))  # noqa: E501
        if 'header_row' in local_var_params and local_var_params['header_row'] is not None:  # noqa: E501
            query_params.append(('headerRow', local_var_params['header_row']))  # noqa: E501
        if 'send_notification' in local_var_params and local_var_params['send_notification'] is not None:  # noqa: E501
            query_params.append(('sendNotification', local_var_params['send_notification']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/csv-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_csv_to_file(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in CSV format. The id of the file is returned in the response.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_to_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_csv_to_file_with_http_info(**kwargs)  # noqa: E501

    def export_csv_to_file_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in CSV format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in CSV format. The id of the file is returned in the response.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_csv_to_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated
        :param str separator: The delimiter character used to separate entries. Default value is <code>';'</code>
        :param str quote: The delimiter character used for quoted entries. Default value  is <code>'\"'</code>
        :param str escape: The delimiter character used to escape separator or quote character. Default value is <code>'\\\\'</code>
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>
        :param str body: The JSON representation of TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileInfoImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'separator',
            'quote',
            'escape',
            'header_row',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_csv_to_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'separator' in local_var_params and local_var_params['separator'] is not None:  # noqa: E501
            query_params.append(('separator', local_var_params['separator']))  # noqa: E501
        if 'quote' in local_var_params and local_var_params['quote'] is not None:  # noqa: E501
            query_params.append(('quote', local_var_params['quote']))  # noqa: E501
        if 'escape' in local_var_params and local_var_params['escape'] is not None:  # noqa: E501
            query_params.append(('escape', local_var_params['escape']))  # noqa: E501
        if 'header_row' in local_var_params and local_var_params['header_row'] is not None:  # noqa: E501
            query_params.append(('headerRow', local_var_params['header_row']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/csv-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_excel_in_job(self, **kwargs):  # noqa: E501
        """Exports results in Excel format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in Excel format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p></p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_excel_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str sheet_name: The name of the sheet. By default no sheet name is set.
        :param bool use_xlsx: Whether the Excel file to export will be '.xlsx' file (<code>true</code>) or a '.xls' file (<code>false</code>. Default value is true.<br/>The parameter will be removed. In the future only XLSX files will be supported..
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON/YAML representation of TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_excel_in_job_with_http_info(**kwargs)  # noqa: E501

    def export_excel_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in Excel format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in Excel format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p></p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_excel_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str sheet_name: The name of the sheet. By default no sheet name is set.
        :param bool use_xlsx: Whether the Excel file to export will be '.xlsx' file (<code>true</code>) or a '.xls' file (<code>false</code>. Default value is true.<br/>The parameter will be removed. In the future only XLSX files will be supported..
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON/YAML representation of TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'send_notification',
            'validation_enabled',
            'file_name',
            'sheet_name',
            'use_xlsx',
            'header_row',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_excel_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'send_notification' in local_var_params and local_var_params['send_notification'] is not None:  # noqa: E501
            query_params.append(('sendNotification', local_var_params['send_notification']))  # noqa: E501
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'sheet_name' in local_var_params and local_var_params['sheet_name'] is not None:  # noqa: E501
            query_params.append(('sheetName', local_var_params['sheet_name']))  # noqa: E501
        if 'use_xlsx' in local_var_params and local_var_params['use_xlsx'] is not None:  # noqa: E501
            query_params.append(('useXLSX', local_var_params['use_xlsx']))  # noqa: E501
        if 'header_row' in local_var_params and local_var_params['header_row'] is not None:  # noqa: E501
            query_params.append(('headerRow', local_var_params['header_row']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/excel-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_excel_to_file(self, **kwargs):  # noqa: E501
        """Exports results in Excel format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in Excel format. The id of the file is returned in the response.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_excel_to_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str sheet_name: The name of the sheet. By default no sheet name is set.
        :param bool use_xlsx: Whether the Excel file to export will be '.xlsx' file (<code>true</code>) or a '.xls' file (<code>false</code>. Default value is true.<br/>The parameter will be removed. In the future only XLSX files will be supported.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON/YAML representation of TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_excel_to_file_with_http_info(**kwargs)  # noqa: E501

    def export_excel_to_file_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in Excel format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in Excel format. The id of the file is returned in the response.</p><p>Please note that the TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_excel_to_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the TableViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str sheet_name: The name of the sheet. By default no sheet name is set.
        :param bool use_xlsx: Whether the Excel file to export will be '.xlsx' file (<code>true</code>) or a '.xls' file (<code>false</code>. Default value is true.<br/>The parameter will be removed. In the future only XLSX files will be supported.
        :param bool header_row: Whether a response should include a header (<code>true</code>) or not (<code>false</code>). Default value is <code>true</code>.
        :param str body: The JSON/YAML representation of TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileInfoImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'sheet_name',
            'use_xlsx',
            'header_row',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_excel_to_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'sheet_name' in local_var_params and local_var_params['sheet_name'] is not None:  # noqa: E501
            query_params.append(('sheetName', local_var_params['sheet_name']))  # noqa: E501
        if 'use_xlsx' in local_var_params and local_var_params['use_xlsx'] is not None:  # noqa: E501
            query_params.append(('useXLSX', local_var_params['use_xlsx']))  # noqa: E501
        if 'header_row' in local_var_params and local_var_params['header_row'] is not None:  # noqa: E501
            query_params.append(('headerRow', local_var_params['header_row']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/excel-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_json(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the returns results immediately in JSON format.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        kwargs['response_type'] = 'str' # ROR TODO Set because it was returning None
        return self.export_json_with_http_info(**kwargs)  # noqa: E501

    def export_json_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the returns results immediately in JSON format.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_json" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            #['text/plain', 'application/json'])  # noqa: E501
            ['text/plain'])  # noqa: E501 # ROR TODO Updated

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            #['application/json', 'application/x-yaml'])  # noqa: E501
            ['application/json'])  # noqa: E501 # ROR TODO Updated

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_json_in_job(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in JSON format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_json_in_job_with_http_info(**kwargs)  # noqa: E501

    def export_json_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in JSON format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool send_notification: Whether an e-mail must be sent on completion of the job.
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'send_notification',
            'validation_enabled',
            'file_name',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_json_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'send_notification' in local_var_params and local_var_params['send_notification'] is not None:  # noqa: E501
            query_params.append(('sendNotification', local_var_params['send_notification']))  # noqa: E501
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/json-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_json_to_file(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in JSON format. The id of the file is returned in the response.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json_to_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_json_to_file_with_http_info(**kwargs)  # noqa: E501

    def export_json_to_file_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in JSON format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in JSON format. The id of the file is returned in the response.</p><p>Please note that the ViewConfig/TableViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_json_to_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig/TableViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileInfoImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_json_to_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/json-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_xml(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the returns results immediately in XML format.</p><p>Please note that the ViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results).For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_xml_with_http_info(**kwargs)  # noqa: E501

    def export_xml_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns the results immediately.  # noqa: E501

        <p>Performs an Output Module query and exports the returns results immediately in XML format.</p><p>Please note that the ViewConfig’s syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results).For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_xml" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/xml', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_xml_in_job(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in XML format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the ViewConfig's syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml_in_job(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Job
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_xml_in_job_with_http_info(**kwargs)  # noqa: E501

    def export_xml_in_job_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns JSON representation of the async Job.  # noqa: E501

        <p>Starts a job that performs an Output Module query and stores the results in a file in XML format. Id of the file can be retrieved from the <code>message.id</code> property of the job once the job is finished.</p><p>Please note that the ViewConfig's syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml_in_job_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Validation is then performed immediately instead of only when the job is started. Please note that the validation will always take place during the Job execution, regardless of this parameter. Default value is false.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Job, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_xml_in_job" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/xml-job', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Job',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_xml_to_file(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in XML format. The id of the file is returned in the response.</p><p>Please note that the ViewConfig's syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml_to_file(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileInfoImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.export_xml_to_file_with_http_info(**kwargs)  # noqa: E501

    def export_xml_to_file_with_http_info(self, **kwargs):  # noqa: E501
        """Exports results in XML format, returns information about created file.  # noqa: E501

        <p>Performs an Output Module query and stores the query results in a file in XML format. The id of the file is returned in the response.</p><p>Please note that the ViewConfig's syntax validation is not executed by default, see <code>validationEnabled</code></p><p>DGC admin console settings may impact the execution of the query (especially in terms of timeout and a limit on the number of results). For details please consult output module documentation.</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_xml_to_file_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param bool validation_enabled: Determines if the ViewConfig’s syntax should be validated (<code>true</code>) or not (<code>false</code>). Default value is false for backward compatibility reasons but it is strongly advised to always enable this validation.
        :param str file_name: The name of the file. By default the file name will be generated.
        :param str body: The JSON/YAML representation of ViewConfig that describes the query to be performed.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileInfoImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'validation_enabled',
            'file_name',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_xml_to_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'validation_enabled' in local_var_params and local_var_params['validation_enabled'] is not None:  # noqa: E501
            query_params.append(('validationEnabled', local_var_params['validation_enabled']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-yaml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/export/xml-file', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileInfoImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_table_view_config_by_view_id(self, view_id, **kwargs):  # noqa: E501
        """Returns TableViewConfig based on id of given View and its Location.  # noqa: E501

        <b>EXPERIMENTAL</b> Returns Table View Config based on id of given View and its Location. This Table View Config can be used by Output Module to export data as visible in Collibra Data Governance Center User Interface.<p>This endpoint does not guarantee a one-to-one relation between what is visible in the User Interface and what will be exported by using the provided Table View Config. Due to the possibility of adding additional filters through User Interface the result can contain more rows then are visible in the User Interface. In such case the Table View Config produced by this endpoint should be manually adjusted. <p><b>Because obtaining the correct results needs a human intervention, this endpoint should not be used in any kind of automatic processing.</b><p>Example: given page under url https://dgc.collibra.com/glossary?view=133f7f30-033c-4e38-acc2-2c1ac599d19e the view <code>id</code> is <code>133f7f30-033c-4e38-acc2-2c1ac599d19e</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_table_view_config_by_view_id(view_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str view_id: The <code>id</code> of given View. Can be obtained from Collibra Data Governance Center User Interface (required)
        :param str view_location: The Location for which the view shall be generated.Views in Collibra Data Governance Center are available under specific locations.Each location is associated with set of filters that are automatically applied to given view.Setting appropriate View Location will produce Table View Config that describes the data seen under desired location and given View in the best way possible.If this field is not provided then the returned Table View Config is going to have additional filters applied based on viewLocation extracted from database.`  <table><tr><th>viewLocation value </th><th> Corresponding view in Collibra Data Governance Center User Interface</th></tr><tr><td>BUSINESS_GLOSSARY_BUSINESS_ASSETS </td><td> Business Glossary Subpages: Business Assets (/glossary)Glossaries (/glossary/glossaries)</td></tr><tr><td>REFERENCE_DATA_CODEVALUES_AND_SETS </td><td> Reference Data > Code Values/Sets (/reference-data)</td></tr><tr><td>CATALOG_DATA_SETS </td><td> Catalog > Data Sets (/catalog/data-sets)</td><td><tr><td>CATALOG_DATA_DICTIONARY </td><td> Catalog > Data Dictionary (/catalog/data-dictionary)</td></tr><tr><td>CATALOG_TECHNOLOGY_ASSETS </td><td> Catalog > Technology Assets (/catalog/technology-assets)</td></tr><tr><td>DATA_HELPDESK_ISSUES </td><td> Data Helpdesk Subpages: Issues(/data-helpdesk)>Data Quality (/data-helpdesk/data-quality)</td></tr><tr><td>STEWARDSHIP_BUSINESS_DIMENSIONS </td><td> Stewardship > Business Dimensions (/stewardship/business-dimensions)</td></tr><tr><td>POLICY_MANAGER_GOVERNANCE_ASSETS </td><td> Policy Manager > Governance Assets (/policy-manager)</td></tr></table>
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_table_view_config_by_view_id_with_http_info(view_id, **kwargs)  # noqa: E501

    def get_table_view_config_by_view_id_with_http_info(self, view_id, **kwargs):  # noqa: E501
        """Returns TableViewConfig based on id of given View and its Location.  # noqa: E501

        <b>EXPERIMENTAL</b> Returns Table View Config based on id of given View and its Location. This Table View Config can be used by Output Module to export data as visible in Collibra Data Governance Center User Interface.<p>This endpoint does not guarantee a one-to-one relation between what is visible in the User Interface and what will be exported by using the provided Table View Config. Due to the possibility of adding additional filters through User Interface the result can contain more rows then are visible in the User Interface. In such case the Table View Config produced by this endpoint should be manually adjusted. <p><b>Because obtaining the correct results needs a human intervention, this endpoint should not be used in any kind of automatic processing.</b><p>Example: given page under url https://dgc.collibra.com/glossary?view=133f7f30-033c-4e38-acc2-2c1ac599d19e the view <code>id</code> is <code>133f7f30-033c-4e38-acc2-2c1ac599d19e</code>.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_table_view_config_by_view_id_with_http_info(view_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str view_id: The <code>id</code> of given View. Can be obtained from Collibra Data Governance Center User Interface (required)
        :param str view_location: The Location for which the view shall be generated.Views in Collibra Data Governance Center are available under specific locations.Each location is associated with set of filters that are automatically applied to given view.Setting appropriate View Location will produce Table View Config that describes the data seen under desired location and given View in the best way possible.If this field is not provided then the returned Table View Config is going to have additional filters applied based on viewLocation extracted from database.`  <table><tr><th>viewLocation value </th><th> Corresponding view in Collibra Data Governance Center User Interface</th></tr><tr><td>BUSINESS_GLOSSARY_BUSINESS_ASSETS </td><td> Business Glossary Subpages: Business Assets (/glossary)Glossaries (/glossary/glossaries)</td></tr><tr><td>REFERENCE_DATA_CODEVALUES_AND_SETS </td><td> Reference Data > Code Values/Sets (/reference-data)</td></tr><tr><td>CATALOG_DATA_SETS </td><td> Catalog > Data Sets (/catalog/data-sets)</td><td><tr><td>CATALOG_DATA_DICTIONARY </td><td> Catalog > Data Dictionary (/catalog/data-dictionary)</td></tr><tr><td>CATALOG_TECHNOLOGY_ASSETS </td><td> Catalog > Technology Assets (/catalog/technology-assets)</td></tr><tr><td>DATA_HELPDESK_ISSUES </td><td> Data Helpdesk Subpages: Issues(/data-helpdesk)>Data Quality (/data-helpdesk/data-quality)</td></tr><tr><td>STEWARDSHIP_BUSINESS_DIMENSIONS </td><td> Stewardship > Business Dimensions (/stewardship/business-dimensions)</td></tr><tr><td>POLICY_MANAGER_GOVERNANCE_ASSETS </td><td> Policy Manager > Governance Assets (/policy-manager)</td></tr></table>
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'view_id',
            'view_location'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_table_view_config_by_view_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'view_id' is set
        if self.api_client.client_side_validation and ('view_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['view_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `view_id` when calling `get_table_view_config_by_view_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'view_id' in local_var_params:
            path_params['viewId'] = local_var_params['view_id']  # noqa: E501

        query_params = []
        if 'view_location' in local_var_params and local_var_params['view_location'] is not None:  # noqa: E501
            query_params.append(('viewLocation', local_var_params['view_location']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/outputModule/tableViewConfigs/viewId/{viewId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.data_quality_rules_api import DataQualityRulesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestDataQualityRulesApi(unittest.TestCase):
    """DataQualityRulesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.data_quality_rules_api.DataQualityRulesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_data_quality_rule(self):
        """Test case for add_data_quality_rule

        Adds a new data quality rule.  # noqa: E501
        """
        pass

    def test_change_data_quality_rule(self):
        """Test case for change_data_quality_rule

        Changes the data quality rule with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_find_data_quality_rules(self):
        """Test case for find_data_quality_rules

        Returns data quality rules matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_data_quality_rule(self):
        """Test case for get_data_quality_rule

        Returns the DataQualityRule identified by given id.  # noqa: E501
        """
        pass

    def test_remove_data_quality_rule(self):
        """Test case for remove_data_quality_rule

        Removes the DataQualityRule identified by the given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddComplexRelationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'complex_relation_type_id': 'str',
        'legs': 'list[ComplexRelationLegRequest]',
        'attributes': 'dict(str, list[AttributeValue])'
    }

    attribute_map = {
        'id': 'id',
        'complex_relation_type_id': 'complexRelationTypeId',
        'legs': 'legs',
        'attributes': 'attributes'
    }

    def __init__(self, id=None, complex_relation_type_id=None, legs=None, attributes=None, local_vars_configuration=None):  # noqa: E501
        """AddComplexRelationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._complex_relation_type_id = None
        self._legs = None
        self._attributes = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.complex_relation_type_id = complex_relation_type_id
        if legs is not None:
            self.legs = legs
        if attributes is not None:
            self.attributes = attributes

    @property
    def id(self):
        """Gets the id of this AddComplexRelationRequest.  # noqa: E501

        The ID of the new complex relation. Should be unique within all complex relations and assets.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddComplexRelationRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddComplexRelationRequest.

        The ID of the new complex relation. Should be unique within all complex relations and assets.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddComplexRelationRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def complex_relation_type_id(self):
        """Gets the complex_relation_type_id of this AddComplexRelationRequest.  # noqa: E501

        The ID of the type of the complex relation.  # noqa: E501

        :return: The complex_relation_type_id of this AddComplexRelationRequest.  # noqa: E501
        :rtype: str
        """
        return self._complex_relation_type_id

    @complex_relation_type_id.setter
    def complex_relation_type_id(self, complex_relation_type_id):
        """Sets the complex_relation_type_id of this AddComplexRelationRequest.

        The ID of the type of the complex relation.  # noqa: E501

        :param complex_relation_type_id: The complex_relation_type_id of this AddComplexRelationRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and complex_relation_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `complex_relation_type_id`, must not be `None`")  # noqa: E501

        self._complex_relation_type_id = complex_relation_type_id

    @property
    def legs(self):
        """Gets the legs of this AddComplexRelationRequest.  # noqa: E501

         The list of legs that the new complex relation should contain.  # noqa: E501

        :return: The legs of this AddComplexRelationRequest.  # noqa: E501
        :rtype: list[ComplexRelationLegRequest]
        """
        return self._legs

    @legs.setter
    def legs(self, legs):
        """Sets the legs of this AddComplexRelationRequest.

         The list of legs that the new complex relation should contain.  # noqa: E501

        :param legs: The legs of this AddComplexRelationRequest.  # noqa: E501
        :type: list[ComplexRelationLegRequest]
        """

        self._legs = legs

    @property
    def attributes(self):
        """Gets the attributes of this AddComplexRelationRequest.  # noqa: E501

        The attributes that the new complex relation should contain.<br/><u>Example:</u><br/>attributes : {<br/>&emsp;\"00000000-0000-0000-0000-000000003114\": [<br/>&emsp;&emsp;{<br/>&emsp;&emsp;&emsp;\"value\": \"string1\"<br/>&emsp;&emsp;}<br/>&emsp;]<br/>&emsp;\"00000000-0000-0000-0000-000000003115\": [<br/>&emsp;&emsp;{<br/>&emsp;&emsp;&emsp;\"values\": [<br/>&emsp;&emsp;&emsp;&emsp;\"string2\",<br/>&emsp;&emsp;&emsp;&emsp;\"string3\"<br/>&emsp;&emsp;&emsp;]<br/>&emsp;&emsp;}<br/>&emsp;]<br/>}  # noqa: E501

        :return: The attributes of this AddComplexRelationRequest.  # noqa: E501
        :rtype: dict(str, list[AttributeValue])
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this AddComplexRelationRequest.

        The attributes that the new complex relation should contain.<br/><u>Example:</u><br/>attributes : {<br/>&emsp;\"00000000-0000-0000-0000-000000003114\": [<br/>&emsp;&emsp;{<br/>&emsp;&emsp;&emsp;\"value\": \"string1\"<br/>&emsp;&emsp;}<br/>&emsp;]<br/>&emsp;\"00000000-0000-0000-0000-000000003115\": [<br/>&emsp;&emsp;{<br/>&emsp;&emsp;&emsp;\"values\": [<br/>&emsp;&emsp;&emsp;&emsp;\"string2\",<br/>&emsp;&emsp;&emsp;&emsp;\"string3\"<br/>&emsp;&emsp;&emsp;]<br/>&emsp;&emsp;}<br/>&emsp;]<br/>}  # noqa: E501

        :param attributes: The attributes of this AddComplexRelationRequest.  # noqa: E501
        :type: dict(str, list[AttributeValue])
        """

        self._attributes = attributes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddComplexRelationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddComplexRelationRequest):
            return True

        return self.to_dict() != other.to_dict()
